Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(341)

Unified Diff: webrtc/sdk/objc/Framework/Headers/WebRTC/RTCMediaSource.h

Issue 2290583003: iOS: Add ability to specify audio constraints. (Closed)
Patch Set: Update ctor order. Created 4 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: webrtc/sdk/objc/Framework/Headers/WebRTC/RTCMediaSource.h
diff --git a/webrtc/sdk/objc/Framework/Headers/WebRTC/RTCVideoSource.h b/webrtc/sdk/objc/Framework/Headers/WebRTC/RTCMediaSource.h
similarity index 82%
copy from webrtc/sdk/objc/Framework/Headers/WebRTC/RTCVideoSource.h
copy to webrtc/sdk/objc/Framework/Headers/WebRTC/RTCMediaSource.h
index e234c3e0896f6d086bcf47312234034ffdd45ba7..6cfcb7d2ce8f0cc00b5084a529c98ede2908c96b 100644
--- a/webrtc/sdk/objc/Framework/Headers/WebRTC/RTCVideoSource.h
+++ b/webrtc/sdk/objc/Framework/Headers/WebRTC/RTCMediaSource.h
@@ -1,5 +1,5 @@
/*
- * Copyright 2015 The WebRTC project authors. All Rights Reserved.
+ * Copyright 2016 The WebRTC project authors. All Rights Reserved.
*
* Use of this source code is governed by a BSD-style license
* that can be found in the LICENSE file in the root of the source
@@ -22,9 +22,9 @@ typedef NS_ENUM(NSInteger, RTCSourceState) {
NS_ASSUME_NONNULL_BEGIN
RTC_EXPORT
-@interface RTCVideoSource : NSObject
+@interface RTCMediaSource : NSObject
-/** The current state of the RTCVideoSource. */
+/** The current state of the RTCMediaSource. */
@property(nonatomic, readonly) RTCSourceState state;
- (instancetype)init NS_UNAVAILABLE;

Powered by Google App Engine
This is Rietveld 408576698